==> haskell-xcffib-0.8.1-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.8.1
id: xcffib-0.8.1-8LgL91IiDfGFPhb4YtmkxZ
key: xcffib-0.8.1-8LgL91IiDfGFPhb4YtmkxZ
license: LicenseRef-OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
author: Tycho Andersen
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
abi: 327ec34823e72b096c669861019e7c9a
exposed: True
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xcffib-0.8.1
hs-libraries: HSxcffib-0.8.1-8LgL91IiDfGFPhb4YtmkxZ
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    either-5.0.1.1-CVGWTobc9CAGvqoR8zTk69
    filemanip-0.3.6.3-9PjMIGa59w06uv24ZubnTs filepath-1.4.2.1
    language-python-0.5.6-AkoEmDTtd2QJdCwGLwBOuT mtl-2.2.2
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz
    xcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcffib-0.8.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcffib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcffib
version: 0.8.1
id: xcffib-0.8.1-2PVghYKcg9l9xjer6D5swl
key: xcffib-0.8.1-2PVghYKcg9l9xjer6D5swl
license: LicenseRef-OtherLicense
maintainer: Tycho Andersen <tycho@tycho.ws>
author: Tycho Andersen
homepage: http://github.com/tych0/xcffib
synopsis: A cffi-based python binding for X
description:
    A cffi-based python binding for X, comparable to xpyb
category: X11
abi: 50cd1fa2cbfa33dd5b774ff7980754c7
exposed: True
exposed-modules:
    Data.XCB.Python.Parse Data.XCB.Python.PyHelpers
import-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/xcffib-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xcffib-0.8.1
hs-libraries: HSxcffib-0.8.1-2PVghYKcg9l9xjer6D5swl
depends:
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1
    either-5.0.1.1-Ax4XTE9eW9CLjFPWgYXrO
    filemanip-0.3.6.3-9PjMIGa59w06uv24ZubnTs filepath-1.4.2.1
    language-python-0.5.6-AkoEmDTtd2QJdCwGLwBOuT mtl-2.2.2
    split-0.2.3.3-6ARGTwZCeo0EpQtAl0OgPz
    xcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
haddock-interfaces: /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html: /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
